Getting Started
=================

.. note::

  This page is under construction. Feel free to send through suggestions or questions.

Set up
-------
To use this software you need in install Python. `Anaconda <https://www.anaconda.com/>`__
is a great way to install python and included popular software for editing and interacting
with python script such as `Spyder <https://www.spyder-ide.org/>`__ and
`Jupyter <https://jupyter.org/>`__.

Installation
--------------
.. seealso::

  `Installation <../installation.html>`__

For in depth installation processes see the page above. For most purposes you
should be able to install **autopew** by typing the following in a terminal ("Anaconda Prompt"
application on your computer if you're using Anaconda)

.. code-block:: bash

   pip install autopew

If you're already installed autopew and would like the most up-to-date version,
type this into a terminal:

.. code-block:: bash

   pip install --upgrade autopew

Writing and editing code
---------------------------
**autopew** is designed to be very beginner friendly, but if you're completely
new to python consider visiting some free online courses about the basic Python
concepts. `Codecademy <https://www.codecademy.com/>`__ is a great jumping off
point.
